# Ansible <Product> Role

<!-- A brief single paragraph description goes here. Use concise, action-oriented
single sentences, streamlining details like in the example below. -->

- [Requirements](#requirements)
- [Role Variables](#role-variables)
- [Handlers](#handlers)
- [Dependencies](#dependencies)
- [Example Playbook](#example-playbook)

## Requirements

<!-- Any pre-requisites that may not be covered by Ansible itself or the role should
be mentioned here. For instance, if the role uses the EC2 module, it may be a
good idea to mention in this section that the boto package is required. -->

## Role Variables

<!-- A description of the settable variables for this role should go here, including
any variables that are in `defaults/main.yml`, `vars/main.yml`. Create a level 3
section for each variable, monospaced using backticks followed with colon and a
very short action-oriented single sentence as description. In each variable
section, describe the variable use, details. If there are many variables, group
variables in sections, with other words add extra grouping level and use level 4
section for each variable.

If there are a large number of variables, that require little explanation, a
comment for example suffices, consider group multiple variables in a level 3
section and then using table for example similar to below.

| Variable                | Required | Default | Choices                   | Comments                                 |
|-------------------------|----------|---------|---------------------------|------------------------------------------|
| foo                     | no       | false   | true, false               | example variable                         |
| bar                     | yes      |         | eggs, spam                | example variable                         | -->

## Handlers

<!-- A description of the handlers role should go here. Create a level 3 section for
each handler name, monospaced using backticks. In each handler section provide a
short action-oriented description of the handler. -->

## Dependencies

<!-- A list of other roles hosted on Galaxy should go here, plus any details in
regards to parameters that may need to be set for other roles, or variables that
are used from other roles. -->

## Example Playbook

<!-- Including an example of the YAML code for an example playbook, including `vars`
sections for notable, typical parameters. -->
